Transfer functions (dsptoolbox.transfer\_functions)
==========================================================

.. automodule:: dsptoolbox.transfer_functions
   :members:
   :undoc-members:
   :show-inheritance:
